# Welcome to GrimoireELK

GrimoireELK is a prototype of the *Grimoire Open Development Analytics platform*. Some use cases are published under the [use_cases](https://github.com/grimoirelab/use_cases) repo. Have a look and enjoy them!
